@@ -6,9 +6,19 @@
 @Desc  : spark配置
 '''
 
-class JKSparkConf(object):
+from pyspark.sql import SparkSession
+
+class JKSparkSession(object):
 
     _options = {}
+    _spark = SparkSession \
+        .builder \
+        .master("yarn")\
+        .enableHiveSupport()
+
+    @classmethod
+    def appName(cls,name):
+        return cls._spark.appName(name)
 
     @classmethod
     def config(cls,key,value):
@@ -17,9 +27,9 @@ class JKSparkConf(object):
 
     @classmethod
     def get(cls):
-        from jklwcs.select.uuid import  set_spark_conf
         for key, value in cls._options.items():
-            set_spark_conf(key,value)
-
+            cls._spark.config(key,value)
+        cls._spark.getOrCreate()
+        return cls._spark
 
 
